from osbot_utils.helpers.duration.decorators.capture_duration                          import capture_duration
from osbot_utils.type_safe.type_safe_core.decorators.type_safe                         import type_safe
from osbot_aws.apis.Session                                                            import Session
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Detect_Sentiment             import Schema__Comprehend__Detect_Sentiment
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Detect_Key_Phrases           import Schema__Comprehend__Detect_Key_Phrases
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Detect_Entities              import Schema__Comprehend__Detect_Entities
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Detect_Dominant_Language     import Schema__Comprehend__Detect_Dominant_Language
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Detect_Pii_Entities          import Schema__Comprehend__Detect_Pii_Entities
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Detect_Syntax                import Schema__Comprehend__Detect_Syntax
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Detect_Toxic_Content         import Schema__Comprehend__Detect_Toxic_Content
from osbot_aws.aws.comprehend.schemas.enums.Enum__Comprehend__Language_Code            import Enum__Comprehend__Language_Code
from osbot_aws.aws.comprehend.schemas.safe_str.Safe_Str__AWS_Comprehend__Text          import Safe_Str__Comprehend__Text
from osbot_aws.aws.session.Session__Kwargs                                             import Session__Kwargs
from osbot_utils.decorators.methods.cache_on_self                                      import cache_on_self
from osbot_utils.type_safe.Type_Safe                                                   import Type_Safe


class Comprehend(Type_Safe):
    session_kwargs      : Session__Kwargs

    @cache_on_self
    def client(self):
        return self.session().client(service_name = 'comprehend'                     ,
                                     region_name  = self.session_kwargs.region_name  ,
                                     endpoint_url =  self.session_kwargs.endpoint_url)


    def session(self):
        return Session()

    @type_safe
    def detect_sentiment(self, text          : Safe_Str__Comprehend__Text                                              ,
                               language_code : Enum__Comprehend__Language_Code = Enum__Comprehend__Language_Code.ENGLISH,
                          ) -> Schema__Comprehend__Detect_Sentiment:
        with capture_duration() as duration:
            result = self.client().detect_sentiment(Text         = text         ,
                                                    LanguageCode = language_code.value)

        sentiment       = result.get('Sentiment')
        sentiment_score = result.get('SentimentScore')

        detect_sentiment = Schema__Comprehend__Detect_Sentiment(duration  = duration.seconds,
                                                                sentiment = sentiment      ,
                                                                score     = dict(mixed    = sentiment_score.get('Mixed'   ),
                                                                                 neutral  = sentiment_score.get('Neutral' ),
                                                                                 negative = sentiment_score.get('Negative'),
                                                                                 positive = sentiment_score.get('Positive')))
        return detect_sentiment

    @type_safe
    def detect_key_phrases(self, text          : Safe_Str__Comprehend__Text                                              ,
                                 language_code : Enum__Comprehend__Language_Code = Enum__Comprehend__Language_Code.ENGLISH,
                            ) -> Schema__Comprehend__Detect_Key_Phrases:
        with capture_duration() as duration:
            result = self.client().detect_key_phrases(Text         = text         ,
                                                      LanguageCode = language_code)

        key_phrases_list = []
        for phrase in result.get('KeyPhrases', []):
            key_phrases_list.append(dict(text         = phrase.get('Text'       ),
                                         score        = phrase.get('Score'      ),
                                         begin_offset = phrase.get('BeginOffset'),
                                         end_offset   = phrase.get('EndOffset'  )))

        return Schema__Comprehend__Detect_Key_Phrases(
            key_phrases = key_phrases_list,
            duration    = duration.seconds
        )

    @type_safe
    def detect_entities(self, text          : Safe_Str__Comprehend__Text                                              ,
                              language_code : Enum__Comprehend__Language_Code = Enum__Comprehend__Language_Code.ENGLISH,
                         ) -> Schema__Comprehend__Detect_Entities:
        with capture_duration() as duration:
            result = self.client().detect_entities(Text         = text         ,
                                                   LanguageCode = language_code)

        entities_list = []
        for entity in result.get('Entities', []):
            entities_list.append(dict(text         = entity.get('Text'       ),
                                      type         = entity.get('Type'       ),
                                      score        = entity.get('Score'      ),
                                      begin_offset = entity.get('BeginOffset'),
                                      end_offset   = entity.get('EndOffset'  )))

        return Schema__Comprehend__Detect_Entities(entities = entities_list   ,
                                                   duration = duration.seconds)

    @type_safe
    def detect_dominant_language(self, text: Safe_Str__Comprehend__Text
                                  ) -> Schema__Comprehend__Detect_Dominant_Language:
        with capture_duration() as duration:
            result = self.client().detect_dominant_language(Text = text)

        languages_list = []
        for language in result.get('Languages', []):
            languages_list.append(dict(language_code = language.get('LanguageCode'),
                                       score         = language.get('Score')))

        return Schema__Comprehend__Detect_Dominant_Language(languages = languages_list  ,
                                                            duration  = duration.seconds)

    @type_safe
    def detect_pii_entities(self, text          : Safe_Str__Comprehend__Text                                              ,
                                  language_code : Enum__Comprehend__Language_Code = Enum__Comprehend__Language_Code.ENGLISH,
                             ) -> Schema__Comprehend__Detect_Pii_Entities:
        with capture_duration() as duration:
            result = self.client().detect_pii_entities(Text         = text         ,
                                                       LanguageCode = language_code)

        entities_list = []
        for entity in result.get('Entities', []):
            entities_list.append(dict(type         = entity.get('Type'       ),
                                      score        = entity.get('Score'      ),
                                      begin_offset = entity.get('BeginOffset'),
                                      end_offset   = entity.get('EndOffset'  )))

        return Schema__Comprehend__Detect_Pii_Entities(entities = entities_list   ,
                                                       duration = duration.seconds)

    @type_safe
    def detect_syntax(self, text          : Safe_Str__Comprehend__Text                                              ,
                            language_code : Enum__Comprehend__Language_Code = Enum__Comprehend__Language_Code.ENGLISH,
                       ) -> Schema__Comprehend__Detect_Syntax:
        with capture_duration() as duration:
            result = self.client().detect_syntax(Text         = text         ,
                                                 LanguageCode = language_code)

        tokens_list = []
        for token in result.get('SyntaxTokens', []):
            pos = token.get('PartOfSpeech', {})
            tokens_list.append(dict(text           = token.get('Text'       ),
                                    token_id       = token.get('TokenId'    ),
                                    begin_offset   = token.get('BeginOffset'),
                                    end_offset     = token.get('EndOffset'  ),
                                    part_of_speech = dict(tag   = pos.get('Tag'  ),
                                                          score = pos.get('Score'))))

        return Schema__Comprehend__Detect_Syntax(syntax_tokens = tokens_list     ,
                                                 duration      = duration.seconds)

    @type_safe
    def detect_toxic_content(self, text          : Safe_Str__Comprehend__Text                                              ,
                                   language_code : Enum__Comprehend__Language_Code = Enum__Comprehend__Language_Code.ENGLISH,
                              ) -> Schema__Comprehend__Detect_Toxic_Content:
        with capture_duration() as duration:
            result = self.client().detect_toxic_content(TextSegments = [{'Text': text}],
                                                        LanguageCode = language_code)


        result_blocks = result.get('ResultList', [])
        labels_list   = []

        if result_blocks:
            first_result = result_blocks[0]
            for label in first_result.get('Labels', []):
                labels_list.append(dict(name  = label.get('Name' ),
                                        score = label.get('Score')))

        return Schema__Comprehend__Detect_Toxic_Content(labels   = labels_list     ,
                                                        duration = duration.seconds)


from osbot_aws.aws.comprehend.Comprehend            import Comprehend
from osbot_aws.aws.iam.IAM_Assume_Role              import IAM_Assume_Role
from osbot_utils.decorators.methods.cache_on_self   import cache_on_self
from osbot_utils.utils.Env                          import load_dotenv


class Comprehend__with_temp_role(Comprehend):


    def iam_assume_role(self):
        load_dotenv()
        services        = ["comprehend"]
        action          = "*"
        resource        = "*"
        role_name       = 'osbot__temp_role_for__test_Comprehend'
        policies_to_add = []
        for service in services:
            policies_to_add.append(dict(service=service, action=action, resource=resource))
        iam_assume_role = IAM_Assume_Role(role_name=role_name, policies_to_add=policies_to_add)
        iam_assume_role.create_role(recreate=False)
        #iam_assume_role.credentials_reset()
        return iam_assume_role


    @cache_on_self
    def client(self):
        service = "comprehend"
        return self.iam_assume_role().boto3_client(service_name=service)


from osbot_utils.type_safe.Type_Safe                                                              import Type_Safe
from osbot_aws.aws.comprehend.schemas.enums.Enum__Comprehend__Language_Code                       import Enum__Comprehend__Language_Code
from osbot_utils.type_safe.primitives.domains.numerical.safe_float.Safe_Float__Probability_Score  import Safe_Float__Probability_Score


class Schema__Comprehend__Language(Type_Safe):
    language_code : Enum__Comprehend__Language_Code
    score         : Safe_Float__Probability_Score


from typing                                                                   import List
from osbot_utils.type_safe.Type_Safe                                          import Type_Safe
from osbot_utils.type_safe.primitives.core.Safe_Float                         import Safe_Float
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Toxic_Content_Label import Schema__Comprehend__Toxic_Content_Label


class Schema__Comprehend__Detect_Toxic_Content(Type_Safe):
    labels   : List[Schema__Comprehend__Toxic_Content_Label]
    duration : Safe_Float


from typing                                                     import List
from osbot_utils.type_safe.Type_Safe                            import Type_Safe
from osbot_utils.type_safe.primitives.core.Safe_Float           import Safe_Float
from osbot_aws.aws.comprehend.Schema__Comprehend__Syntax_Token  import Schema__Comprehend__Syntax_Token


class Schema__Comprehend__Detect_Syntax(Type_Safe):
    syntax_tokens : List[Schema__Comprehend__Syntax_Token]
    duration      : Safe_Float


from enum import Enum


class Enum__Comprehend__Pii_Entity_Type(str, Enum):
    BANK_ACCOUNT_NUMBER                       = "BANK_ACCOUNT_NUMBER"
    BANK_ROUTING                              = "BANK_ROUTING"
    CREDIT_DEBIT_NUMBER                       = "CREDIT_DEBIT_NUMBER"
    CREDIT_DEBIT_CVV                          = "CREDIT_DEBIT_CVV"
    CREDIT_DEBIT_EXPIRY                       = "CREDIT_DEBIT_EXPIRY"
    EMAIL                                     = "EMAIL"
    PHONE                                     = "PHONE"
    NAME                                      = "NAME"
    SSN                                       = "SSN"
    ADDRESS                                   = "ADDRESS"
    DATE_TIME                                 = "DATE_TIME"
    PASSPORT_NUMBER                           = "PASSPORT_NUMBER"
    DRIVER_ID                                 = "DRIVER_ID"
    URL                                       = "URL"
    USERNAME                                  = "USERNAME"
    PASSWORD                                  = "PASSWORD"
    AWS_ACCESS_KEY                            = "AWS_ACCESS_KEY"
    AWS_SECRET_KEY                            = "AWS_SECRET_KEY"
    IP_ADDRESS                                = "IP_ADDRESS"
    MAC_ADDRESS                               = "MAC_ADDRESS"
    LICENSE_PLATE                             = "LICENSE_PLATE"
    VEHICLE_IDENTIFICATION_NUMBER             = "VEHICLE_IDENTIFICATION_NUMBER"
    UK_NATIONAL_INSURANCE_NUMBER              = "UK_NATIONAL_INSURANCE_NUMBER"
    CA_SOCIAL_INSURANCE_NUMBER                = "CA_SOCIAL_INSURANCE_NUMBER"
    US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER   = "US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER"
    UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER       = "UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER"
    IN_PERMANENT_ACCOUNT_NUMBER               = "IN_PERMANENT_ACCOUNT_NUMBER"
    IN_NREGA                                  = "IN_NREGA"
    INTERNATIONAL_BANK_ACCOUNT_NUMBER         = "INTERNATIONAL_BANK_ACCOUNT_NUMBER"
    SWIFT_CODE                                = "SWIFT_CODE"
    UK_NATIONAL_HEALTH_SERVICE_NUMBER         = "UK_NATIONAL_HEALTH_SERVICE_NUMBER"
    CA_HEALTH_NUMBER                          = "CA_HEALTH_NUMBER"
    IN_AADHAAR                                = "IN_AADHAAR"
    IN_VOTER_NUMBER                           = "IN_VOTER_NUMBER"






from osbot_utils.type_safe.Type_Safe                                            import Type_Safe
from osbot_utils.type_safe.primitives.core.Safe_UInt                            import Safe_UInt
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Part_Of_Speech        import Schema__Comprehend__Part_Of_Speech
from osbot_aws.aws.comprehend.schemas.safe_str.Safe_Str__AWS_Comprehend__Text   import Safe_Str__Comprehend__Text


class Schema__Comprehend__Syntax_Token(Type_Safe):
    text          : Safe_Str__Comprehend__Text
    token_id      : Safe_UInt
    begin_offset  : Safe_UInt
    end_offset    : Safe_UInt
    part_of_speech: Schema__Comprehend__Part_Of_Speech


from typing                                                        import List
from osbot_utils.type_safe.Type_Safe                               import Type_Safe
from osbot_utils.type_safe.primitives.core.Safe_Float              import Safe_Float
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Language import Schema__Comprehend__Language


class Schema__Comprehend__Detect_Dominant_Language(Type_Safe):
    languages     : List[Schema__Comprehend__Language]  # Sorted by confidence
    duration      : Safe_Float



from osbot_utils.type_safe.primitives.core.Safe_Float                                       import Safe_Float
from osbot_utils.type_safe.Type_Safe                                                        import Type_Safe
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Detect_Sentiment__Score           import Schema__Comprehend__Detect_Sentiment__Score
from osbot_aws.aws.comprehend.schemas.enums.Enum__Comprehend__Detect_Sentiment__Sentiment   import Enum__Comprehend__Detect_Sentiment__Sentiment


class Schema__Comprehend__Detect_Sentiment(Type_Safe):
    sentiment : Enum__Comprehend__Detect_Sentiment__Sentiment
    score     : Schema__Comprehend__Detect_Sentiment__Score
    duration  : Safe_Float


from osbot_utils.type_safe.Type_Safe                                                              import Type_Safe
from osbot_utils.type_safe.primitives.core.Safe_UInt                                              import Safe_UInt
from osbot_utils.type_safe.primitives.domains.numerical.safe_float.Safe_Float__Probability_Score  import Safe_Float__Probability_Score
from osbot_aws.aws.comprehend.schemas.safe_str.Safe_Str__AWS_Comprehend__Text                     import Safe_Str__Comprehend__Text


class Schema__Comprehend__Key_Phrase(Type_Safe):
    text         : Safe_Str__Comprehend__Text
    score        : Safe_Float__Probability_Score
    begin_offset : Safe_UInt
    end_offset   : Safe_UInt




from osbot_utils.type_safe.Type_Safe                                                               import Type_Safe
from osbot_aws.aws.comprehend.schemas.enums.Enum__Comprehend__Part_Of_Speech_Tag                   import Enum__Comprehend__Part_Of_Speech_Tag
from osbot_utils.type_safe.primitives.domains.numerical.safe_float.Safe_Float__Probability_Score   import Safe_Float__Probability_Score

class Schema__Comprehend__Part_Of_Speech(Type_Safe):
    tag   : Enum__Comprehend__Part_Of_Speech_Tag
    score : Safe_Float__Probability_Score


import re

from osbot_utils.type_safe.primitives.core.Safe_Str import Safe_Str


class Safe_Str__Comprehend__Text(Safe_Str):
    """
    Text input for AWS Comprehend APIs with minimal validation.

    AWS Comprehend analyzes natural language text and needs to receive it unmodified.
    This type ONLY enforces the AWS API byte size limit and allows ALL characters:

    - All UTF-8 characters (any language: English, Spanish, Chinese, Arabic, etc.)
    - All punctuation and symbols (!, @, #, $, %, etc.)
    - All whitespace (spaces, tabs, newlines, etc.)
    - Emojis and special Unicode characters
    - HTML tags, code snippets, URLs
    - ANY text that someone might want to analyze

    AWS Comprehend API Limits:
    - DetectSentiment: 5000 bytes max
    - DetectEntities: 5000 bytes max
    - DetectKeyPhrases: 5000 bytes max
    - DetectDominantLanguage: 5000 bytes max
    - DetectSyntax: 5000 bytes max
    - DetectPiiEntities: 5000 bytes max

      """

    regex           = re.compile(r'[\x00\x01-\x08\x0B\x0C\x0E-\x1F\x7F]')   # allow ALL characters except some control ones
    max_length      = 5000                                                  # AWS Comprehend 5KB limit (conservative char estimate)



from osbot_utils.type_safe.Type_Safe                                                             import Type_Safe
from osbot_utils.type_safe.primitives.domains.numerical.safe_float.Safe_Float__Probability_Score import Safe_Float__Probability_Score


class Schema__Comprehend__Detect_Sentiment__Score(Type_Safe):
    mixed    : Safe_Float__Probability_Score
    negative : Safe_Float__Probability_Score
    neutral  : Safe_Float__Probability_Score
    positive : Safe_Float__Probability_Score


from enum                                                import Enum


class Enum__Comprehend__Language_Code(str, Enum):
    """
    AWS Comprehend supported language codes (RFC 5646 format).

    Amazon Comprehend supports analysis in the following languages:
    - Uses ISO 639-1 2-letter codes when available
    - Falls back to ISO 639-2 3-letter codes when needed

    Note: DetectDominantLanguage can detect 100+ languages but returns RFC 5646 codes.
    This enum covers the languages supported for sentiment, entities, key phrases, and syntax.
    """

    # Most commonly used languages
    ENGLISH            = "en"       # English
    SPANISH            = "es"       # Spanish
    FRENCH             = "fr"       # French
    GERMAN             = "de"       # German (Deutsch)
    ITALIAN            = "it"       # Italian
    PORTUGUESE         = "pt"       # Portuguese

    # Asian languages
    JAPANESE           = "ja"       # Japanese
    KOREAN             = "ko"       # Korean
    CHINESE_SIMPLIFIED = "zh"       # Chinese (Simplified)
    CHINESE_TRADITIONAL= "zh-TW"    # Chinese (Traditional)
    HINDI              = "hi"       # Hindi

    # Middle Eastern languages
    ARABIC             = "ar"       # Arabic

    # Additional supported languages (varies by API operation)
    AFRIKAANS          = "af"       # Afrikaans
    ALBANIAN           = "sq"       # Albanian
    AMHARIC            = "am"       # Amharic
    ARMENIAN           = "hy"       # Armenian
    AZERBAIJANI        = "az"       # Azerbaijani
    BENGALI            = "bn"       # Bengali
    BOSNIAN            = "bs"       # Bosnian
    BULGARIAN          = "bg"       # Bulgarian
    CATALAN            = "ca"       # Catalan
    CROATIAN           = "hr"       # Croatian
    CZECH              = "cs"       # Czech
    DANISH             = "da"       # Danish
    DARI               = "fa-AF"    # Dari
    DUTCH              = "nl"       # Dutch
    ESTONIAN           = "et"       # Estonian
    FARSI              = "fa"       # Farsi (Persian)
    FILIPINO           = "tl"       # Filipino/Tagalog
    FINNISH            = "fi"       # Finnish
    GEORGIAN           = "ka"       # Georgian
    GREEK              = "el"       # Greek
    GUJARATI           = "gu"       # Gujarati
    HAUSA              = "ha"       # Hausa
    HEBREW             = "he"       # Hebrew
    HUNGARIAN          = "hu"       # Hungarian
    INDONESIAN         = "id"       # Indonesian
    IRISH              = "ga"       # Irish
    KANNADA            = "kn"       # Kannada
    KAZAKH             = "kk"       # Kazakh
    LATVIAN            = "lv"       # Latvian
    LITHUANIAN         = "lt"       # Lithuanian
    MACEDONIAN         = "mk"       # Macedonian
    MALAY              = "ms"       # Malay
    MALAYALAM          = "ml"       # Malayalam
    MALTESE            = "mt"       # Maltese
    MARATHI            = "mr"       # Marathi
    MONGOLIAN          = "mn"       # Mongolian
    NEPALI             = "ne"       # Nepali
    NORWEGIAN          = "no"       # Norwegian
    PASHTO             = "ps"       # Pashto
    POLISH             = "pl"       # Polish
    PUNJABI            = "pa"       # Punjabi
    ROMANIAN           = "ro"       # Romanian
    RUSSIAN            = "ru"       # Russian
    SERBIAN            = "sr"       # Serbian
    SINHALA            = "si"       # Sinhala
    SLOVAK             = "sk"       # Slovak
    SLOVENIAN          = "sl"       # Slovenian
    SOMALI             = "so"       # Somali
    SWAHILI            = "sw"       # Swahili
    SWEDISH            = "sv"       # Swedish
    TAMIL              = "ta"       # Tamil
    TELUGU             = "te"       # Telugu
    THAI               = "th"       # Thai
    TURKISH            = "tr"       # Turkish
    UKRAINIAN          = "uk"       # Ukrainian
    URDU               = "ur"       # Urdu
    UZBEK              = "uz"       # Uzbek
    VIETNAMESE         = "vi"       # Vietnamese
    WELSH              = "cy"       # Welsh


from typing                                                             import List
from osbot_utils.type_safe.Type_Safe                                    import Type_Safe
from osbot_utils.type_safe.primitives.core.Safe_Float                   import Safe_Float
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Key_Phrase    import Schema__Comprehend__Key_Phrase


class Schema__Comprehend__Detect_Key_Phrases(Type_Safe):
    key_phrases  : List[Schema__Comprehend__Key_Phrase]
    duration     : Safe_Float


from typing                                                          import List
from osbot_utils.type_safe.Type_Safe                                 import Type_Safe
from osbot_utils.type_safe.primitives.core.Safe_Float                import Safe_Float
from osbot_aws.aws.comprehend.schemas.Schema__Comprehend__Pii_Entity import Schema__Comprehend__Pii_Entity


class Schema__Comprehend__Detect_Pii_Entities(Type_Safe):
    entities     : List[Schema__Comprehend__Pii_Entity]
    duration     : Safe_Float


from osbot_utils.type_safe.Type_Safe                                                             import Type_Safe
from osbot_aws.aws.comprehend.schemas.enums.Enum__Comprehend__Toxic_Content_Label                import Enum__Comprehend__Toxic_Content_Label
from osbot_utils.type_safe.primitives.domains.numerical.safe_float.Safe_Float__Probability_Score import Safe_Float__Probability_Score


class Schema__Comprehend__Toxic_Content_Label(Type_Safe):
    name  : Enum__Comprehend__Toxic_Content_Label
    score : Safe_Float__Probability_Score


from enum import Enum


class Enum__Comprehend__Entity_Type(str, Enum):
    PERSON          = "PERSON"
    LOCATION        = "LOCATION"
    ORGANIZATION    = "ORGANIZATION"
    COMMERCIAL_ITEM = "COMMERCIAL_ITEM"
    EVENT           = "EVENT"
    DATE            = "DATE"
    QUANTITY        = "QUANTITY"
    TITLE           = "TITLE"
    OTHER           = "OTHER"


from enum import Enum


class Enum__Comprehend__Part_Of_Speech_Tag(str, Enum):
    ADJ   = "ADJ"      # Adjective
    ADP   = "ADP"      # Adposition
    ADV   = "ADV"      # Adverb
    AUX   = "AUX"      # Auxiliary
    CCONJ = "CCONJ"    # Coordinating conjunction
    DET   = "DET"      # Determiner
    INTJ  = "INTJ"     # Interjection
    NOUN  = "NOUN"     # Noun
    NUM   = "NUM"      # Numeral
    PART  = "PART"     # Particle
    PRON  = "PRON"     # Pronoun
    PROPN = "PROPN"    # Proper noun
    PUNCT = "PUNCT"    # Punctuation
    SCONJ = "SCONJ"    # Subordinating conjunction
    SYM   = "SYM"      # Symbol
    VERB  = "VERB"     # Verb
    OTHER = "O"        # Other


from enum import Enum


class Enum__Comprehend__Toxic_Content_Label(str, Enum):
    """
    AWS Comprehend toxicity detection label types.

    These labels identify different categories of toxic or harmful content
    that may violate community guidelines or terms of service.
    """
    PROFANITY           = "PROFANITY"              # Swear words, curses, obscene language
    HATE_SPEECH         = "HATE_SPEECH"            # Attacks on protected groups (race, religion, etc.)
    INSULT              = "INSULT"                 # Personal attacks, name-calling
    GRAPHIC             = "GRAPHIC"                # Violent, gory, or disturbing content
    HARASSMENT_OR_ABUSE = "HARASSMENT_OR_ABUSE"    # Bullying, threats, intimidation
    SEXUAL              = "SEXUAL"                 # Sexual content or innuendo
    VIOLENCE_OR_THREAT  = "VIOLENCE_OR_THREAT"     # Threats of violence or harm


from osbot_utils.type_safe.Type_Safe                                                             import Type_Safe
from osbot_utils.type_safe.primitives.core.Safe_UInt                                             import Safe_UInt
from osbot_aws.aws.comprehend.schemas.enums.Enum__Comprehend__Pii_Entity_Type                    import Enum__Comprehend__Pii_Entity_Type
from osbot_utils.type_safe.primitives.domains.numerical.safe_float.Safe_Float__Probability_Score import Safe_Float__Probability_Score


class Schema__Comprehend__Pii_Entity(Type_Safe):
    type         : Enum__Comprehend__Pii_Entity_Type
    score        : Safe_Float__Probability_Score
    begin_offset : Safe_UInt
    end_offset   : Safe_UInt